==> aliyun-python-sdk-videorecog-1.0.2.tar.gz: aliyun-python-sdk-videorecog-1.0.2/aliyunsdkvideorecog/request/v20200320/GenerateVideoCoverRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkvideorecog.endpoint import endpoint_data

class GenerateVideoCoverRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'videorecog', '2020-03-20', 'GenerateVideoCover','videorecog')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_IsGif(self):
		return self.get_body_params().get('IsGif')

	def set_IsGif(self,IsGif):
		self.add_body_params('IsGif', IsGif)

	def get_VideoUrl(self):
		return self.get_body_params().get('VideoUrl')

	def set_VideoUrl(self,VideoUrl):
		self.add_body_params('VideoUrl', VideoUrl)

==> aliyun-python-sdk-videorecog-1.0.9.tar.gz: aliyun-python-sdk-videorecog-1.0.9/aliyunsdkvideorecog/request/v20200320/GenerateVideoCoverRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkvideorecog.endpoint import endpoint_data

class GenerateVideoCoverRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'videorecog', '2020-03-20', 'GenerateVideoCover','videorecog')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_IsGif(self): # Boolean
		return self.get_body_params().get('IsGif')

	def set_IsGif(self, IsGif):  # Boolean
		self.add_body_params('IsGif', IsGif)
	def get_VideoUrl(self): # String
		return self.get_body_params().get('VideoUrl')

	def set_VideoUrl(self, VideoUrl):  # String
		self.add_body_params('VideoUrl', VideoUrl)
